/*
 * (c) Copyright Robin Hill 2002
 *
 * For license terms, see the file COPYING in this directory.
 */
	
/* Parameters used */
wxString        ChkFile,
                InputFile,
                ServerAddress,
		HashType;
long            blocksize,
                port;
bool            passive,
		quiet,
                ignore;

/* Rows within the curses interface used for different tasks */
#define ROW_BLANK  0  /* Start with a blank row */
#define ROW_HEAD   1  /* Print the heading info (app no, version, etc) */
#define ROW_STAT1  2  /* Two rows for status information */
#define ROW_STAT2  3
#define ROW_SCINF  4  /* One row for server/client info messages */
#define ROW_PROG1  5  /* The top border of the progress bar */
#define ROW_PROG2  6  /* The progress bar itself */
#define ROW_PROG3  7  /* The bottom border of the progress bar */
#define ROW_RES1   8  /* Two rows for the results/error messages */
#define ROW_RES2   9

void RunJob(wxString header, wxUint32 mode);

/* A console interface to the backend processes, outputting via curses */
class FRCLI_BackEnd : public FR_BackEnd
{
public:
	FRCLI_BackEnd();

	wxString lastMessage;

private:
	void SendError(const wxString message);
	void SendAlert(const wxString message);
	void SendProgress(wxInt8 progress);
	void SendStatus(const wxString message);
	void SendServerInfo(const wxString message);
	void SendHash(const wxString message);
	bool CheckExit();
	bool ContinueWrongFilesize(const wxString message);
	void Sleep(unsigned long duration);
};

enum
{
	/* Thread modes */
	MODE_FH_ED2K = 1000,
	MODE_FH_MD5,
	MODE_FH_CRC,
	MODE_FH_TTH,
	MODE_CRC_CREATE,
	MODE_CRC_VERIFY,
	MODE_CLIENT_START,
	MODE_SERVER_START,

	/* Event signals from threads */
	THREAD_STARTED = 2000,
	THREAD_STATUS,
	THREAD_ALERT,
	THREAD_ERROR,
	THREAD_PROGRESS,
	THREAD_HASH,
	THREAD_SRVINFO,
	THREAD_CLNTINFO
};
