/*
 * (c) Copyright Robin Hill 2002
 *
 * For license terms, see the file COPYING in this directory.
 */
	
class FileRepairApp : public wxApp
{
public:
	virtual bool OnInit();
};

#if wxUSE_DRAG_AND_DROP
class FileNameDrop : public wxFileDropTarget
{
public:
	FileNameDrop(wxTextCtrl *pOwner) { m_pOwner = pOwner; }

	bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& filenames);
private:
	wxTextCtrl *m_pOwner;
};
#endif

class FileRepairDlg : public wxFrame
{
public:
	FileRepairDlg(const wxString& title, const wxPoint& pos, const wxSize& size);

	/* Event handlers (these functions should _not_ be virtual) */
	void OnQuit(wxCommandEvent& event);
	void OnClose(wxCloseEvent& event);
	void OnFileBrowse(wxCommandEvent& WXUNUSED(event));
	void OnChecksumBrowse(wxCommandEvent& WXUNUSED(event));
	void edtFileNameChange(wxCommandEvent& WXUNUSED(event));
	void edtChecksumFileChange(wxCommandEvent& WXUNUSED(event));
	void tabModeChanging(wxNotebookEvent& event);
	void CheckButtons(wxCommandEvent& WXUNUSED(event));
	void OnFileHashClick(wxCommandEvent& WXUNUSED(event));
	void OnChecksumCreateClick(wxCommandEvent& WXUNUSED(event));
	void OnChecksumVerifyClick(wxCommandEvent& WXUNUSED(event));
	void OnClientStartClick(wxCommandEvent& WXUNUSED(event));
	void OnServerStartClick(wxCommandEvent& WXUNUSED(event));
	void OnStopClick(wxCommandEvent& WXUNUSED(event));
	void StartThread(wxUint32 mode);
	void ChangeState(wxCommandEvent& event);
	void ErrorMessage(wxCommandEvent& event);
	void AlertMessage(wxCommandEvent& event);
	void ProgressMessage(wxCommandEvent& event);
	void HashMessage(wxCommandEvent& event);
	void StatusMessage(wxCommandEvent& event);
	void ServerMessage(wxCommandEvent& event);
	void About(wxCommandEvent& WXUNUSED(event));
	void HelpContents(wxCommandEvent& WXUNUSED(event));
	void HelpIndex(wxCommandEvent& WXUNUSED(event));
	/* Set icon (from wxFrame source code) */
	virtual void SetIcon(const wxIcon& icon);

	/* Global variables */
	wxString        ChkFile,
	                InputFile,
	                ServerAddress;
	bool            passive;
	long            blocksize,
	                port;
	wxThread        *SecondThread;

private:
	/* Global controls */
	wxTextCtrl      *edtFileName;
	wxButton        *btnFileBrowse,
	                *btnQuit;
	wxNotebook      *tabMode;
	wxStaticText    *edtStatus;
	wxGauge         *barProgress;

	/* Standalone tab controls */
	wxPanel         *tabStandalone;
	wxChoice        *chcFileHash;
	wxButton        *btnFileHash,
	                *btnChecksumBrowse,
	                *btnChecksumCreate,
	                *btnChecksumVerify;
	wxTextCtrl      *edtHashResult,
	                *edtChecksumFile,
	                *edtBlocksize;
	wxStaticBox     *boxCreateHash,
	                *boxCRC32;
	wxStaticText    *labFileHash,
                    *labChecksumFile,
	                *labBlocksize,
	                *labBlocksizeMul;

	/* Client tab controls */
	wxPanel         *tabClient;
	wxStaticBox     *boxClientSetup;
	wxStaticText    *labServerAddress,
	                *labClientPort,
	                *labClientBlocksize,
	                *labClientBlocksizeMul,
	                *labClientResults;
	wxTextCtrl      *edtServerAddress,
	                *edtClientPort,
	                *edtClientBlocksize;
	wxCheckBox      *chkClientPassive;
	wxButton        *btnClientStart,
	                *btnClientStop;

	/* Server tab controls */
	wxPanel         *tabServer;
	wxStaticBox     *boxServerSetup;
	wxStaticText    *labServerPort,
	                *labServerResults;
	wxTextCtrl      *edtServerPort;
	wxCheckBox      *chkServerPassive;
	wxButton        *btnServerStart,
	                *btnServerStop;

	/* Dialog icon */
	wxIcon          m_icon;

	/* Help contoller */
	wxHtmlHelpController *frHelp;

	/* Any class wishing to process wxWindows events must use this macro */
	DECLARE_EVENT_TABLE()
};

enum
{
	/* Text controls */
	FR_FileName = 1,
	FR_HashResult,
	FR_ChecksumFile,
	FR_Blocksize,
	FR_ServerAddress,
	FR_ClientPort,
	FR_ClientBlocksize,
	FR_ServerPort,

	/* Buttons controls */
	FR_FileBrowse = 100,
	FR_Quit,
	FR_FileHash,
	FR_ChecksumBrowse,
	FR_ChecksumCreate,
	FR_ChecksumVerify,
	FR_ClientStart,
	FR_ClientStop,
	FR_ServerStart,
	FR_ServerStop,

	/* Menu items */
	FR_MenuFileExit = 200,
	FR_MenuHelpContents,
	FR_MenuHelpIndex,
	FR_MenuHelpAbout,

	/* Others controls */
	FR_MainPanel = 300,
	FR_FileNameLab,
	FR_ModeTab,
	FR_StandaloneTab,
	FR_ClientTab,
	FR_ServerTab,
	FR_Status,
	FR_ProgressBar,
	FR_CreateHash,
	FR_CRC32,
	FR_ChecksumFileLab,
	FR_BlocksizeLab,
	FR_BlocksizeMul,
	FR_ClientSetup,
	FR_ServerAddressLab,
	FR_ClientPortLab,
	FR_ClientBlocksizeLab,
	FR_ClientBlocksizeMul,
	FR_ClientPassive,
	FR_ClientResults,
	FR_ServerSetup,
	FR_ServerPortLab,
	FR_ServerPassive,
	FR_ServerResults,
	FR_FileHashType,
	FR_FileHashLab,

	/* Thread modes */
	MODE_FH_ED2K = 1000,
	MODE_FH_MD5,
	MODE_FH_CRC,
	MODE_FH_TTH,
	MODE_CRC_CREATE,
	MODE_CRC_VERIFY,
	MODE_CLIENT_START,
	MODE_SERVER_START,

	/* Event signals from threads */
	THREAD_STARTED = 2000,
	THREAD_STATUS,
	THREAD_ALERT,
	THREAD_ERROR,
	THREAD_PROGRESS,
	THREAD_HASH,
	THREAD_SRVINFO
};
